@@ -1,7 +1,6 @@
 import json
 import time
 from abc import ABC
-from enum import Enum
 from functools import lru_cache
 from typing import Type, List, cast, Dict, Any
 
@@ -10,12 +9,12 @@ from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.processor import ProcessorBase, ProcessorParameters
 from pymultirole_plugins.v1.schema import Document, Sentence
 from pymultirole_plugins.v1.segmenter import SegmenterParameters, SegmenterBase
-from pysegmenters_rules_segmenter.pysbd_sentencizer import PySBDSentencizer
-from pysegmenters_rules_segmenter.rules_sentencizer import RuleSentencizer
 from spacy.cli.download import download_model, get_compatibility, get_version
 from spacy.language import Language
 from wasabi import msg
 
+from pysegmenters_rules_segmenter.rules_sentencizer import RuleSentencizer
+
 SPLIT_DEFAULT = [
     [
         {
@@ -88,19 +87,9 @@ JOIN_DEFAULT = [
 ]
 
 
-class RuleEngine(str, Enum):
-    PySBD = 'PySBD'
-    Custom = 'Custom'
-    Spacy = 'Spacy'
-
-
 class RulesSegmenterParameters(SegmenterParameters, ProcessorParameters, ABC):
     lang: str = Field("en",
                       description="Name of the 2-letter language of the documents")
-    engine: RuleEngine = Field(RuleEngine.PySBD,
-                               description="""Rule engine to use for segmentation, can be one of:, can be one of:<br/>
-                            <li>`PySBD`: [python Sentence Boundary Disambiguation](https://github.com/nipunsadvilkar/pySBD) (SBD) - is a rule-based sentence boundary detection module that works out-of-the-box.
-                            <li>`Custom`: use [Spacy Rules](https://spacy.io/usage/rule-based-matching) defined in the following parameters `split_rules` and `join_rules`.""")
     split_rules: List[List[Dict[str, Any]]] = Field(SPLIT_DEFAULT,
                                                     description="""List of split rules_segmenter that operates over tokens based on the [Spacy Rule-based matcher](https://spacy.io/usage/rule-based-matching) syntax<br/>
     The rules_segmenter can refer to token annotations (e.g. the token text and flags (e.g. IS_PUNCT), the sentence start always at the last token a of sequence.<br/>
@@ -141,7 +130,7 @@ class RulesSegmenterParameters(SegmenterParameters, ProcessorParameters, ABC):
 
 
 class RulesSegmenter(SegmenterBase, ProcessorBase, ABC):
-    """Rule-based segmenter relying on [PySBD](https://github.com/nipunsadvilkar/pySBD) or custom [Spacy Rules](https://spacy.io/usage/rule-based-matching).
+    """Rule-based segmenter relying on custom [Spacy Rules](https://spacy.io/usage/rule-based-matching).
     """
 
     def segment(self, documents: List[Document], parameters: SegmenterParameters) \
@@ -171,18 +160,12 @@ class RulesSegmenter(SegmenterBase, ProcessorBase, ABC):
 
 
 def get_sentencizer_from_params(params):
-    engine = params.engine.value
-    if engine == RuleEngine.Custom:
-        json_split = json_rules_to_string(params.split_rules)
-        json_join = json_rules_to_string(params.join_rules)
-        return get_custom_sentencizer(params.lang,
-                                     json_split,
-                                     json_join,
-                                     ttl_hash=get_ttl_hash())
-    elif engine == RuleEngine.PySBD:
-        return get_pysbd_sentencizer(params.lang, ttl_hash=get_ttl_hash())
-    elif engine == RuleEngine.Spacy:
-        return get_spacy_sentencizer(params.lang, ttl_hash=get_ttl_hash())
+    json_split = json_rules_to_string(params.split_rules)
+    json_join = json_rules_to_string(params.join_rules)
+    return get_custom_sentencizer(params.lang,
+                                  json_split,
+                                  json_join,
+                                  ttl_hash=get_ttl_hash())
 
 
 def json_rules_to_string(json_rules: List[List[Dict[str, Any]]]):
@@ -231,15 +214,6 @@ def get_custom_sentencizer(lang: str, json_split: str, json_join: str, ttl_hash=
     return nlp, enable_pipes
 
 
-@lru_cache(maxsize=None)
-def get_pysbd_sentencizer(lang: str, ttl_hash=None):
-    nlp = get_nlp(lang, exclude=("parser", "tagger", "ner", "lemmatizer"), ttl_hash=ttl_hash)
-    unique_name = "sentencizer_pysbd"
-    sentencizer: PySBDSentencizer = nlp.add_pipe("pysbd_sentencizer", name=unique_name)
-    enable_pipes = [p for p in nlp.pipe_names if not p.startswith("sentencizer_") or p == sentencizer.name]
-    return nlp, enable_pipes
-
-
 @lru_cache(maxsize=None)
 def get_spacy_sentencizer(lang: str, ttl_hash=None):
     nlp = get_nlp(lang, exclude=tuple(), ttl_hash=ttl_hash)
